fisx: fisx::EPDL97 Class Reference

fisx

Public Member Functions | List of all members
fisx::EPDL97 Class Reference

## Public Member Functions
| EPDL97 (std::string directoryName)
void | setDataDirectory (std::string directoryName)
void | loadBindingEnergies (std::string fileName)
void | setBindingEnergies (const int &z, const std::map< std::string, double > &bindingEnergies)
const std::map< std::string, double > & | getBindingEnergies (const int &z)
std::map< std::string, double > | getMassAttenuationCoefficients (const int &z, const double &energy) const
std::map< std::string, std::vector< double > > | getMassAttenuationCoefficients (const int &z, const std::vector< double > &energy) const
std::map< std::string, std::vector< double > > | getMassAttenuationCoefficients (const int &z) const
std::map< std::string, double > | getPhotoelectricWeights (const int &z, const double &energy)
std::map< std::string, std::vector< double > > | getPhotoelectricWeights (const int &z, const std::vector< double > &energy)
std::string | toUpperCaseString (const std::string &) const
std::pair< long, long > | getInterpolationIndices (const std::vector< double > &, const double &) const

The documentation for this class was generated from the following files:

- fisx_epdl97.h
- fisx_epdl97.cpp